package com.newfiber.voice.thrid.impl;

import com.newfiber.voice.config.VoiceProperties;
import com.newfiber.voice.enums.VoiceFormatEnum;
import com.newfiber.voice.thrid.ThridCallbackService;
import com.newfiber.voice.thrid.VoiceService;
import com.newfiber.voice.thrid.request.AudioRecognitionRequest;
import com.newfiber.voice.thrid.request.AudioRecognitionResponse;
import com.newfiber.voice.thrid.request.AudioSynthesisRequest;
import com.newfiber.voice.thrid.request.RealtimeRecognitionRequest;
import com.tencent.asr.model.FlashRecognitionRequest;
import com.tencent.asr.model.FlashRecognitionResponse;
import com.tencent.asr.service.FlashRecognizer;
import com.tencent.asrv2.AsrConstant;
import com.tencent.asrv2.SpeechRecognizer;
import com.tencent.asrv2.SpeechRecognizerRequest;
import com.tencent.core.utils.ByteUtils;
import com.tencent.core.ws.Credential;
import com.tencent.core.ws.SpeechClient;
import com.tencent.ttsv2.SpeechSynthesizer;
import com.tencent.ttsv2.SpeechSynthesizerRequest;
import com.tencent.ttsv2.TtsConstant;
import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

@Service
/* loaded from: TencentVoiceServiceImpl.class */
public class TencentVoiceServiceImpl implements VoiceService {

    @Resource
    private ThridCallbackService thridCallbackService;
    private VoiceProperties.VoiceThridConfig voiceThridConfig;
    static Logger logger = LoggerFactory.getLogger(TencentVoiceServiceImpl.class);
    static SpeechClient speechRecognizerProxy = new SpeechClient(AsrConstant.DEFAULT_RT_REQ_URL);
    static SpeechClient speechSynthesizerProxy = new SpeechClient(TtsConstant.DEFAULT_TTS_REQ_URL);

    public TencentVoiceServiceImpl(VoiceProperties.VoiceThridConfig voiceThridProperties) {
        this.voiceThridConfig = voiceThridProperties;
    }

    public void realtimeRecognition(RealtimeRecognitionRequest realtimeRecognitionRequest) {
        Credential credential = new Credential(this.voiceThridConfig.getAppId(), this.voiceThridConfig.getSecretId(), this.voiceThridConfig.getSecretKey());
        SpeechRecognizerRequest request = SpeechRecognizerRequest.init();
        request.setEngineModelType("16k_zh");
        VoiceFormatEnum voiceFormatEnum = VoiceFormatEnum.match(realtimeRecognitionRequest.getVoiceType());
        if (voiceFormatEnum != null) {
            request.setVoiceFormat(voiceFormatEnum.getValue());
        }
        request.setVoiceId(realtimeRecognitionRequest.getVoiceId());
        1 r0 = new 1(this, realtimeRecognitionRequest);
        SpeechRecognizer speechRecognizer = null;
        try {
            try {
                int subByteNum = 1280;
                if (realtimeRecognitionRequest.getVoiceType().equals(VoiceFormatEnum.MP3.getCode())) {
                    subByteNum = 640;
                }
                List<byte[]> speechData = ByteUtils.subToSmallBytes(realtimeRecognitionRequest.getFileInputStream(), subByteNum);
                speechRecognizer = new SpeechRecognizer(speechRecognizerProxy, credential, request, r0);
                speechRecognizer.start();
                for (int i = 0; i < speechData.size(); i++) {
                    speechRecognizer.write(speechData.get(i));
                    Thread.sleep(20L);
                }
                speechRecognizer.stop();
                if (speechRecognizer != null) {
                    speechRecognizer.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
                if (speechRecognizer != null) {
                    speechRecognizer.close();
                }
            }
        } catch (Throwable th) {
            if (speechRecognizer != null) {
                speechRecognizer.close();
            }
            throw th;
        }
    }

    public AudioRecognitionResponse audioRecognition(AudioRecognitionRequest audiRecognitionRequest) {
        com.tencent.asr.model.Credential credential = com.tencent.asr.model.Credential.builder().secretId(this.voiceThridConfig.getSecretId()).secretKey(this.voiceThridConfig.getSecretKey()).build();
        FlashRecognizer recognizer = com.tencent.SpeechClient.newFlashRecognizer(this.voiceThridConfig.getAppId(), credential);
        byte[] data = ByteUtils.inputStream2ByteArray(audiRecognitionRequest.getAudioPath());
        FlashRecognitionRequest recognitionRequest = FlashRecognitionRequest.initialize();
        recognitionRequest.setEngineType("16k_zh");
        recognitionRequest.setFirstChannelOnly(1);
        recognitionRequest.setVoiceFormat(audiRecognitionRequest.getAudioType());
        recognitionRequest.setSpeakerDiarization(0);
        recognitionRequest.setFilterDirty(0);
        recognitionRequest.setFilterModal(0);
        recognitionRequest.setFilterPunc(0);
        recognitionRequest.setConvertNumMode(1);
        recognitionRequest.setWordInfo(1);
        FlashRecognitionResponse response = recognizer.recognize(recognitionRequest, data);
        AudioRecognitionResponse result = new AudioRecognitionResponse();
        if (response != null) {
            result.setErrorMessage(response.getMessage());
            if (response.getCode().intValue() == 0) {
                result.setRecognitionState(1);
                result.setAudioDuration(response.getAudioDuration());
                List<FlashRecognitionResponse.FlashRecognitionResult> flashResult = response.getFlashResult();
                result.setRecognitionResult((String) flashResult.stream().map((v0) -> {
                    return v0.getText();
                }).collect(Collectors.joining()));
            } else {
                result.setRecognitionState(0);
            }
        }
        return result;
    }

    public void audioSynthesis(AudioSynthesisRequest audioSynthesisRequest) {
        Credential credential = new Credential(this.voiceThridConfig.getAppId(), this.voiceThridConfig.getSecretId(), this.voiceThridConfig.getSecretKey());
        SpeechSynthesizerRequest request = new SpeechSynthesizerRequest();
        request.setText(audioSynthesisRequest.getText());
        request.setVoiceType(301032);
        request.setVolume(Float.valueOf(0.0f));
        request.setSpeed(Float.valueOf(-1.0f));
        request.setCodec("mp3");
        request.setSampleRate(16000);
        request.setEnableSubtitle(true);
        request.setEmotionCategory("call");
        request.setEmotionIntensity(100);
        request.setSessionId(audioSynthesisRequest.getSessionId());
        SpeechSynthesizer synthesizer = null;
        try {
            try {
                synthesizer = new SpeechSynthesizer(speechSynthesizerProxy, credential, request, new 2(this, audioSynthesisRequest));
                synthesizer.start();
                synthesizer.stop();
                if (synthesizer != null) {
                    synthesizer.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
                if (synthesizer != null) {
                    synthesizer.close();
                }
            }
        } catch (Throwable th) {
            if (synthesizer != null) {
                synthesizer.close();
            }
            throw th;
        }
    }
}
